Module ident

Module ident 

Structs

CanonicalClassKeyV0
ClassNameV0
A CSS class name with authored and decoded spellings.
ClassSelectorNameV0
ClassSelectorPositionV0

Functions

class_selector_name_end
class_selector_names
css_identifier_escape_sequence_end
Returns the byte immediately after a valid CSS identifier escape.
decode_css_identifier_escapes
is_ascii_word_continue
Returns whether a character belongs to the deliberately narrow ASCII word used by completion and hover cursor boundaries.
is_css_name_continue
Returns whether a decoded character can continue a CSS identifier name.
is_css_name_start
Returns whether a decoded character can start a CSS identifier name.
is_safe_css_identifier